@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: stock.cc 413 2005-07-10 19:24:22Z murrayc $ */
+/* $Id: stock.cc 848 2007-06-09 20:03:39Z murrayc $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -56,6 +56,7 @@ const Gtk::BuiltinStockID COPY = { GTK_STOCK_COPY };
 const Gtk::BuiltinStockID CUT = { GTK_STOCK_CUT };
 const Gtk::BuiltinStockID DELETE = { GTK_STOCK_DELETE };
 const Gtk::BuiltinStockID DIRECTORY = { GTK_STOCK_DIRECTORY };
+const Gtk::BuiltinStockID DISCARD = { GTK_STOCK_DISCARD };
 const Gtk::BuiltinStockID DISCONNECT = { GTK_STOCK_DISCONNECT };
 const Gtk::BuiltinStockID EDIT = { GTK_STOCK_EDIT };
 const Gtk::BuiltinStockID EXECUTE = { GTK_STOCK_EXECUTE };
@@ -112,6 +113,7 @@ const Gtk::BuiltinStockID REMOVE = { GTK_STOCK_REMOVE };
 const Gtk::BuiltinStockID REVERT_TO_SAVED = { GTK_STOCK_REVERT_TO_SAVED };
 const Gtk::BuiltinStockID SAVE = { GTK_STOCK_SAVE };
 const Gtk::BuiltinStockID SAVE_AS = { GTK_STOCK_SAVE_AS };
+const Gtk::BuiltinStockID SELECT_ALL = { GTK_STOCK_SELECT_ALL };
 const Gtk::BuiltinStockID SELECT_COLOR = { GTK_STOCK_SELECT_COLOR };
 const Gtk::BuiltinStockID SELECT_FONT = { GTK_STOCK_SELECT_FONT };
 const Gtk::BuiltinStockID SORT_ASCENDING = { GTK_STOCK_SORT_ASCENDING };
